%{?mingw_package_header}

Name:           mingw-jasper
Version:        3.0.6
Release:        %mkrel 1
Summary:        MinGW Windows Jasper library

License:        JasPer-2.0
Group:          Development/Other

URL:            https://www.ece.uvic.ca/~frodo/jasper/
Source0:        https://github.com/mdadams/jasper/archive/version-%{version}/jasper-%{version}.tar.gz

# MinGW-specific patches.
# Version the library
Patch1:         jasper-libversion.patch
# Add some missing exports, needed by mingw-gdal
Patch2:         jasper-exports.patch
# Backport patch for CVE-2022-2963
Patch3:         https://patch-diff.githubusercontent.com/raw/jasper-software/jasper/pull/333.patch

BuildArch:      noarch

BuildRequires:  make

BuildRequires:  cmake
BuildRequires:  mingw32-filesystem >= 95
BuildRequires:  mingw32-gcc
BuildRequires:  mingw32-libjpeg

BuildRequires:  mingw64-filesystem >= 95
BuildRequires:  mingw64-gcc
BuildRequires:  mingw64-libjpeg


%description
MinGW Windows Jasper library.


%package -n mingw32-jasper
Summary:        MinGW Windows Jasper library

%description -n mingw32-jasper
MinGW Windows Jasper library.


%package -n mingw32-jasper-static
Summary:        Static version of the MinGW Windows Jasper library
Requires:       mingw32-jasper = %{version}-%{release}

%description -n mingw32-jasper-static
Static version of the MinGW Windows Jasper library.


%package -n mingw64-jasper
Summary:        MinGW Windows Jasper library

%description -n mingw64-jasper
MinGW Windows Jasper library.


%package -n mingw64-jasper-static
Summary:        Static version of the MinGW Windows Jasper library
Requires:       mingw64-jasper = %{version}-%{release}

%description -n mingw64-jasper-static
Static version of the MinGW Windows Jasper library.


%{?mingw_debug_package}


%prep
%autosetup -p1 -n jasper-version-%{version}


%build
jasper_cmake_args="-DJAS_ENABLE_DOC=OFF -DJAS_ENABLE_OPENGL=OFF -DJAS_ENABLE_AUTOMATIC_DEPENDENCIES=OFF -DJAS_STDC_VERSION=201112L"
# Build static
MINGW_BUILDDIR_SUFFIX=-static %mingw_cmake -DJAS_ENABLE_SHARED=OFF $jasper_cmake_args
MINGW_BUILDDIR_SUFFIX=-static %mingw_make_build
# Build shared
MINGW_BUILDDIR_SUFFIX=-shared %mingw_cmake -DJAS_ENABLE_SHARED=ON $jasper_cmake_args
MINGW_BUILDDIR_SUFFIX=-shared %mingw_make_build


%install
MINGW_BUILDDIR_SUFFIX=-static %mingw_make_install
MINGW_BUILDDIR_SUFFIX=-shared %mingw_make_install

# Remove documentation
rm -rf %{buildroot}%{mingw32_mandir}
rm -rf %{buildroot}%{mingw64_mandir}
rm -rf %{buildroot}%{mingw32_docdir}
rm -rf %{buildroot}%{mingw64_docdir}
rmdir %{buildroot}%{mingw32_datadir}
rmdir %{buildroot}%{mingw64_datadir}


%files -n mingw32-jasper
%license COPYRIGHT.txt LICENSE.txt
%{mingw32_bindir}/imgcmp.exe
%{mingw32_bindir}/imginfo.exe
%{mingw32_bindir}/jasper.exe
%{mingw32_bindir}/libjasper-6.dll
%{mingw32_libdir}/libjasper.dll.a
%{mingw32_libdir}/pkgconfig/jasper.pc
%{mingw32_includedir}/jasper/

%files -n mingw32-jasper-static
%{mingw32_libdir}/libjasper.a

%files -n mingw64-jasper
%license COPYRIGHT.txt LICENSE.txt
%{mingw64_bindir}/imgcmp.exe
%{mingw64_bindir}/imginfo.exe
%{mingw64_bindir}/jasper.exe
%{mingw64_bindir}/libjasper-6.dll
%{mingw64_libdir}/libjasper.dll.a
%{mingw64_libdir}/pkgconfig/jasper.pc
%{mingw64_includedir}/jasper/

%files -n mingw64-jasper-static
%{mingw64_libdir}/libjasper.a



%changelog
* Mon Nov 21 2022 daviddavid <daviddavid> 3.0.6-1.mga9
+ Revision: 1909821
- new version 3.0.6

* Fri Mar 25 2022 umeabot <umeabot> 2.0.28-2.mga9
+ Revision: 1825484
- Mageia 9 Mass Rebuild

* Thu Apr 01 2021 daviddavid <daviddavid> 2.0.28-1.mga9
+ Revision: 1712330
- new version: 2.0.28

* Wed Mar 24 2021 daviddavid <daviddavid> 2.0.27-1.mga9
+ Revision: 1709094
- new version: 2.0.27

* Sat Mar 06 2021 daviddavid <daviddavid> 2.0.26-1.mga9
+ Revision: 1700136
- new version: 2.0.26

* Mon Feb 08 2021 daviddavid <daviddavid> 2.0.25-1.mga8
+ Revision: 1675058
- new version: 2.0.25, fixes CVE-2021-3272 (mga#28318)

* Thu Jan 14 2021 luigiwalser <luigiwalser> 2.0.23-2.mga8
+ Revision: 1671688
- rebuild for missing signature

* Tue Dec 15 2020 daviddavid <daviddavid> 2.0.23-1.mga8
+ Revision: 1657799
- new version: 2.0.23
- remove merged upstream patch

* Mon Dec 14 2020 daviddavid <daviddavid> 2.0.22-2.mga8
+ Revision: 1657390
- Backport patch for jasper_CVE-2020-27828.patch
- Export symbols needed by mingw-gdal

* Wed Oct 07 2020 daviddavid <daviddavid> 2.0.22-1.mga8
+ Revision: 1632574
- new version: 2.0.22

* Sat Sep 26 2020 tv <tv> 2.0.19-2.mga8
+ Revision: 1630265
- rebuild for new mingw stack

* Thu Aug 06 2020 daviddavid <daviddavid> 2.0.19-1.mga8
+ Revision: 1611421
- new version: 2.0.19

* Sun Feb 16 2020 umeabot <umeabot> 2.0.16-2.mga8
+ Revision: 1534557
- Mageia 8 Mass Rebuild

* Fri Oct 04 2019 daviddavid <daviddavid> 2.0.16-1.mga8
+ Revision: 1449368
- new version: 2.0.16

* Wed Aug 28 2019 daviddavid <daviddavid> 2.0.14-1.mga8
+ Revision: 1434932
- new version: 2.0.14

* Wed Sep 19 2018 umeabot <umeabot> 1.900.1-29.mga7
+ Revision: 1264334
- Mageia 7 Mass Rebuild

* Thu Apr 07 2016 neoclust <neoclust> 1.900.1-28.mga6
+ Revision: 999098
- Sync with fc24
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.900.1-24.mga5
+ Revision: 744272
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.900.1-23.mga5
+ Revision: 682463
- Mageia 5 Mass Rebuild

* Sat Oct 26 2013 neoclust <neoclust> 1.900.1-22.mga4
+ Revision: 547008
- imported package mingw-jasper


* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.900.1-22
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.900.1-21
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.900.1-20
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed Mar 14 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 1.900.1-19
- Eliminated the libtool hack

* Wed Mar 14 2012 Kalev Lember <kalevlember@gmail.com> - 1.900.1-18
- Build 64 bit Windows binaries

* Fri Mar 09 2012 Kalev Lember <kalevlember@gmail.com> - 1.900.1-17
- Remove .la files

* Tue Mar 06 2012 Kalev Lember <kalevlember@gmail.com> - 1.900.1-16
- Renamed the source package to mingw-jasper (#800426)
- Spec clean up
- Use mingw macros without leading underscore

* Mon Feb 27 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 1.900.1-15
- Rebuild against the mingw-w64 toolchain

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.900.1-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Fri Jun 03 2011 Kalev Lember <kalev@smartlink.ee> - 1.900.1-13
- Rebuilt with mingw32-libjpeg-turbo

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.900.1-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Sep 18 2009 Erik van Pienbroek <epienbro@fedoraproject.org> - 1.900.1-11
- Rebuild because of broken mingw32-gcc/mingw32-binutils

* Thu Aug 27 2009 Erik van Pienbroek <epienbro@fedoraproject.org> - 1.900.1-10
- Rebuild for mingw32-libjpeg 7
- Automatically generate debuginfo subpackage
- Added -static subpackage
- Use %%global instead of %%define

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.900.1-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon Mar  9 2009 Richard W.M. Jones <rjones@redhat.com> - 1.900.1-8
- Fix defattr line.
- Remove the enable-shared patch, and just use --enable-shared on
  the configure line.
- Disable the GL patch since OpenGL is disabled.
- Document what the patches are for in the spec file.
- Only patch Makefile.in so we don't have to rerun autotools, and
  remove autotools dependency.

* Fri Feb 20 2009 Richard W.M. Jones <rjones@redhat.com> - 1.900.1-7
- Rebuild for mingw32-gcc 4.4

* Fri Jan 23 2009 Richard W.M. Jones <rjones@redhat.com> - 1.900.1-6
- Use _smp_mflags.
- Disable static libraries.
- Include documentation.
- Use the same patches as Fedora native package.
- Just run autoconf instead of autoreconf so we don't upgrade libtool.
- +BR mingw32-dlfcn.
- Don't need the manual pages.

* Wed Sep 24 2008 Richard W.M. Jones <rjones@redhat.com> - 1.900.1-5
- Rename mingw -> mingw32.

* Mon Sep 22 2008 Daniel P. Berrange <berrange@redhat.com> - 1.900.1-4
- Add overflow patch from rawhide

* Thu Sep 11 2008 Daniel P. Berrange <berrange@redhat.com> - 1.900.1-3
- Run autoreconf after changing configure.ac script and add BRs for autotools

* Wed Sep 10 2008 Richard W.M. Jones <rjones@redhat.com> - 1.900.1-2
- Enable DLLs.
- Remove static libraries.

* Tue Sep  9 2008 Daniel P. Berrange <berrange@redhat.com> - 1.900.1-1
- Initial RPM release
